/*
 *  Copyright (C) 2008  Thadeu Lima de Souza Cascardo <cascardo@holoscopio.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */


#include <atompub/atom.h>

#include <glib.h>

#include <string.h>

struct _atom_request
{
  int type;
  char *request;
  char *content;
  size_t content_len;
};

AtomRequest *
atom_request_new (int type, char *request)
{
  AtomRequest *req;
  req = g_slice_new (AtomRequest);
  req->type = type;
  req->request = g_strdup (request);
  req->content = NULL;
  req->content_len = 0;
  return req;
}

void
atom_request_delete (AtomRequest *req)
{
  if (req->request)
    g_free (req->request);
  if (req->content)
    g_free (req->content);
  g_slice_free (AtomRequest, req);
}

int
atom_request_type (AtomRequest *req)
{
  return req->type;
}

char *
atom_request_request (AtomRequest *req)
{
  return req->request;
}

void
atom_request_content_set (AtomRequest *req, char *content, size_t len)
{
  if (req->content)
    g_free (req->content);
  req->content = g_malloc (len);
  memcpy (req->content, content, len);
  req->content_len = len;
}

void
atom_request_content (AtomRequest *req, char **content, size_t *len)
{
  if (content)
    *content = req->content;
  if (len)
    *len = req->content_len;
}
